package tsp.csc4509.dm.graphique;

import java.awt.Color;

public class ColorieurSwing {
	/**
	 * La matrice des couleurs à calculer.
	 */
	private Color [][] couleurs;
	/**
	 * La valeur maximale des entiers de la matrices de valeurs.
	 */
	private int valeurMax;
	/**
	 * La matrice des valeurs à traduire en couleurs.
	 */
	private int [][] valeurs;


	/**
	 * Contructeur de la classe qui initialise la matrice des valeurs, et la valeur max.
	 * @param valeurs
	 *               la matrice des valeurs à traduire en couleur.
	 * @param valeurMax
	 *               la valeur max.
	 */
	public ColorieurSwing(final int [][] valeurs, final int valeurMax) {
		int nbX = valeurs.length;
		int nbY = valeurs[0].length;
		couleurs = new Color [nbX][nbY];
		this.valeurMax = valeurMax;
		this.valeurs = valeurs;
	}


	/**
	 * Transforme la matrice des valeurs en une matrice de couleurs.
	 */
	public void colorier() {
		for (int indX = 0; indX < couleurs.length; indX++) {
			for (int indY = 0; indY < couleurs[0].length; indY++) {
				double val = valeurs[indX][indY];
				double teinte;
				double lum = 1;
				if (val < valeurMax/10) {
					teinte = Math.sin((val*Math.PI*40)/valeurMax);
				}
				else {
					teinte = Math.sin((val*0.9*Math.PI*6)/valeurMax);
				}
				if (val > 0.9*valeurMax) {
					lum = 10 - (10 * val) / valeurMax;
				}


				val = Math.sin((val*Math.PI*10)/valeurMax);
				couleurs[indX][indY] = Color.getHSBColor((float)teinte, 1 ,(float) lum );
			}
		}
	}

	/**
	 * getter sur la matrice des couleurs.
	 * @return
	 *        la matrice des couleurs.
	 */
	public Color [][] getCouleurs() {
		return couleurs;
	}

}
